@@ -719,6 +719,7 @@ class ExtendedModel(object):
         return asimov_data
 
     def generate_asimov(self, poi_name:str, poi_val:float, poi_profile:Optional[float]=None,
+                        globs_np_matching:bool=False,
                         conditional_mle:bool=True, do_import:bool=True,
                         asimov_name:Optional[str]=None,
                         channel_asimov_name:Optional[str]=None,
@@ -748,6 +749,10 @@ class ExtendedModel(object):
                     the POI at the specified value (POI is fixed if conditional_mle=True, free otherwise) to
                     obtain the best-fit nuisance parameter values before generating the asimov data.
                     category label. Other keywords are: `{index}` which is the category index.
+                globs_np_matching: bool, default=False
+                    Match the values of nuisance parameters and the corresponding global observables when
+                    generating the asimov data. This is important for making sure the asimov data has the 
+                    (conditional) minimal NLL.
                 do_import: bool, default=True
                     Import the generated asimov data to the current workspace.                    
                 conditional_mle: bool, default=True
@@ -838,6 +843,8 @@ class ExtendedModel(object):
         else:
             ws.saveSnapshot(con_glob_name.format(mu=poi_val), globs)
             ws.saveSnapshot(con_nuis_name.format(mu=poi_val), nuis)
+
+        if not globs_np_matching:
             ws.loadSnapshot(nom_glob_name)
             ws.loadSnapshot(nom_nuis_name)
             
